@@ -40,7 +40,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : touch_extension_object(0), handle(0) {}
+            Resource() : touch_extension_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             qt_touch_extension *touch_extension_object;
@@ -66,8 +66,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -94,6 +94,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -108,6 +109,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            qt_touch_extension *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 }
 
